.. _getting_started:

Getting started
================================

.. toctree::
   :maxdepth: 1

   getting_started_running_agox
   getting_started_statistics
   getting_started_slurm
   getting_started_understanding_the_script
   getting_started_other_algorithms